pub enum DataFormat {
RDFXml,
Turtle,
NTriples,
NQuads,
}Expand description
DataFormat
Represents the format in which the data are serialized, for example when returned by a query or when inserted in the store.
Variants