pub struct ConstructQuery {
pub prefixes: Vec<Prefix>,
pub construct: Vec<TripleConstructTemplate>,
pub where: WhereClause,
}Expand description
ConstructQuery
Represents a CONSTRUCT query over the triple store, allowing to retrieve a set of triples serialized in a specific format.
Fields
prefixes: Vec<Prefix>The prefixes used in the query.
construct: Vec<TripleConstructTemplate>The triples to construct.
If nothing is provided and the where clause is a single Bgp, the patterns are used for
construction.
where: WhereClauseThe WHERE clause. This clause is used to specify the triples to construct using variable bindings.