pub struct DescribeQuery {
pub prefixes: Vec<Prefix>,
pub resource: VarOrNamedNode,
pub where: Option<WhereClause>,
}Expand description
DescribeQuery
Represents a DESCRIBE query over the triple store, allowing to retrieve a description of a resource as a set of triples serialized in a specific format.
Fields
prefixes: Vec<Prefix>The prefixes used in the query.
resource: VarOrNamedNodeThe resource to describe given as a variable or a node.
where: Option<WhereClause>The WHERE clause. This clause is used to specify the resource identifier to describe using variable bindings.