pub struct SelectQuery {
pub prefixes: Vec<Prefix>,
pub select: Vec<SelectItem>,
pub where: WhereClause,
pub limit: Option<u32>,
}Expand description
SelectQuery
Represents a SELECT query over the triple store, allowing to select variables to return and to filter the results.
Fields
prefixes: Vec<Prefix>The prefixes used in the query.
select: Vec<SelectItem>The items to select. Note: the number of items to select cannot exceed the maximum query variable count defined in the store limitations.
where: WhereClauseThe WHERE clause.
If None, there is no WHERE clause, i.e. all triples are returned without filtering.
limit: Option<u32>The maximum number of results to return.
If None, there is no limit.
Note: the value of the limit cannot exceed the maximum query limit defined in the store
limitations.